[PATCH V8 17/36] tests/kms_colorop: Add bypass test
Alex Hung
alex.hung at amd.com
Wed Apr 30 01:34:35 UTC 2025
From: Harry Wentland <harry.wentland at amd.com>
We want to test that setting the color pipeline to bypass
yields the expected results.
Signed-off-by: Harry Wentland <harry.wentland at amd.com>
---
tests/kms_colorop.c | 66 +++++++++++++++++++++++++++++++--------------
1 file changed, 46 insertions(+), 20 deletions(-)
diff --git a/tests/kms_colorop.c b/tests/kms_colorop.c
index 95ccf2c47..83f121073 100644
--- a/tests/kms_colorop.c
+++ b/tests/kms_colorop.c
@@ -30,7 +30,7 @@
* Category: Display
* Description: Test to validate the retrieving and setting of DRM colorops
*
- * SUBTEST: plane-%s
+ * SUBTEST: plane-%s-%s
* Description: Tests DRM colorop properties on a plane
* Driver requirement: amdgpu
* Functionality: kms_core
@@ -39,6 +39,11 @@
*
* arg[1]:
*
+ * @XR24-XR24: XRGB8888 framebuffer and writeback buffer
+ *
+ * arg[2]:
+ *
+ * @bypass: Bypass Color Pipeline
* @srgb_eotf: sRGB EOTF
* @srgb_inv_eotf: sRGB Inverse EOTF
* @srgb_eotf-srgb_inv_eotf: sRGB EOTF -> sRGB Inverse EOTF
@@ -54,11 +59,12 @@
/* TODO move to lib for kms_writeback and kms_colorop (and other future) use */
static bool check_writeback_config(igt_display_t *display, igt_output_t *output,
- drmModeModeInfo override_mode)
+ drmModeModeInfo override_mode, __u32 fourcc_in,
+ __u32 fourcc_out)
{
igt_fb_t input_fb, output_fb;
igt_plane_t *plane;
- uint32_t writeback_format = DRM_FORMAT_XRGB8888;
+ uint32_t writeback_format = fourcc_out;
uint64_t modifier = DRM_FORMAT_MOD_LINEAR;
int width, height, ret;
@@ -68,7 +74,7 @@ static bool check_writeback_config(igt_display_t *display, igt_output_t *output,
height = override_mode.vdisplay;
ret = igt_create_fb(display->drm_fd, width, height,
- DRM_FORMAT_XRGB8888, modifier, &input_fb);
+ fourcc_in, modifier, &input_fb);
igt_assert(ret >= 0);
ret = igt_create_fb(display->drm_fd, width, height,
@@ -101,7 +107,7 @@ typedef struct {
static data_t data;
/* TODO move to lib for kms_writeback and kms_colorop (and other future) use */
-static igt_output_t *kms_writeback_get_output(igt_display_t *display)
+static igt_output_t *kms_writeback_get_output(igt_display_t *display, __u32 fourcc_in, __u32 fourcc_out)
{
int i;
enum pipe pipe;
@@ -137,7 +143,7 @@ static igt_output_t *kms_writeback_get_output(igt_display_t *display)
if (data.builtin_mode)
override_mode = output->config.connector->modes[data.mode_index];
- if (check_writeback_config(display, output, override_mode)) {
+ if (check_writeback_config(display, output, override_mode, fourcc_in, fourcc_out)) {
igt_debug("Using connector %u:%s on pipe %d\n",
output->config.connector->connector_id,
output->name, pipe);
@@ -364,6 +370,8 @@ static void apply_transforms(kms_colorop_t *colorops[], igt_fb_t *sw_transform_f
}
static void colorop_plane_test(igt_display_t *display,
+ __u32 fourcc_in,
+ __u32 fourcc_out,
kms_colorop_t *colorops[])
{
igt_colorop_t *color_pipeline = NULL;
@@ -376,7 +384,7 @@ static void colorop_plane_test(igt_display_t *display,
unsigned int fb_id;
igt_crc_t input_crc, output_crc;
- output = kms_writeback_get_output(display);
+ output = kms_writeback_get_output(display, fourcc_in, fourcc_out);
igt_require(output);
if (output->use_override_mode)
@@ -390,7 +398,7 @@ static void colorop_plane_test(igt_display_t *display,
fb_id = igt_create_color_pattern_fb(display->drm_fd,
mode.hdisplay, mode.vdisplay,
- DRM_FORMAT_XRGB8888, DRM_FORMAT_MOD_LINEAR,
+ fourcc_in, DRM_FORMAT_MOD_LINEAR,
0.2, 0.2, 0.2, &input_fb);
igt_assert(fb_id >= 0);
igt_plane_set_fb(plane, &input_fb);
@@ -400,7 +408,7 @@ static void colorop_plane_test(igt_display_t *display,
/* create output fb */
fb_id = igt_create_fb(display->drm_fd, mode.hdisplay, mode.vdisplay,
- DRM_FORMAT_XRGB8888,
+ fourcc_in,
igt_fb_mod_to_tiling(0),
&output_fb);
igt_require(fb_id > 0);
@@ -439,13 +447,18 @@ static void colorop_plane_test(igt_display_t *display,
#endif
/* discover and set COLOR PIPELINE */
- /* get COLOR_PIPELINE enum */
- color_pipeline = get_color_pipeline(display, plane, colorops);
+ if (!colorops[0]) {
+ /* bypass test */
+ set_color_pipeline_bypass(plane);
+ } else {
+ /* get COLOR_PIPELINE enum */
+ color_pipeline = get_color_pipeline(display, plane, colorops);
- /* skip test if we can't find applicable pipeline */
- igt_skip_on(!color_pipeline);
+ /* skip test if we can't find applicable pipeline */
+ igt_skip_on(!color_pipeline);
- set_color_pipeline(display, plane, colorops, color_pipeline);
+ set_color_pipeline(display, plane, colorops, color_pipeline);
+ }
igt_output_set_writeback_fb(output, &output_fb);
@@ -486,6 +499,7 @@ igt_main
kms_colorop_t *colorops[MAX_COLOROPS];
const char *name;
} tests[] = {
+ { { NULL }, "bypass" },
{ { &kms_colorop_srgb_eotf, NULL }, "srgb_eotf" },
{ { &kms_colorop_srgb_inv_eotf, NULL }, "srgb_inv_eotf" },
{ { &kms_colorop_srgb_eotf, &kms_colorop_srgb_inv_eotf, NULL }, "srgb_eotf-srgb_inv_eotf" },
@@ -498,8 +512,16 @@ igt_main
{ { &kms_colorop_ctm_3x4_bt709_dec, &kms_colorop_ctm_3x4_bt709_enc, NULL }, "ctm_3x4_bt709_dec_enc" },
};
+ struct {
+ __u32 fourcc_in;
+ __u32 fourcc_out;
+ const char *name;
+ } formats[] = {
+ { DRM_FORMAT_XRGB8888, DRM_FORMAT_XRGB8888, "XR24-XR24" },
+ };
+
igt_display_t display;
- int i, ret;
+ int i, j, ret;
igt_fixture {
display.drm_fd = drm_open_driver_master(DRIVER_ANY);
@@ -521,12 +543,16 @@ igt_main
}
- for (i = 0; i < ARRAY_SIZE(tests); i++) {
- igt_describe("Bla bla bla");
- igt_subtest_f("plane-%s", tests[i].name)
- colorop_plane_test(&display, tests[i].colorops);
+ for (j = 0; j < ARRAY_SIZE(formats); j++) {
+ for (i = 0; i < sizeof(tests) / sizeof (tests[0]); i++) {
+ igt_describe("Bla bla bla");
+ igt_subtest_f("plane-%s-%s", formats[j].name, tests[i].name)
+ colorop_plane_test(&display,
+ formats[j].fourcc_in,
+ formats[j].fourcc_out,
+ tests[i].colorops);
+ }
}
-
igt_describe("Tests getting and setting COLOR_PIPELINE property on plane");
#if 0
igt_subtest("plane-srgb") {
--
2.43.0
More information about the igt-dev
mailing list